<?php

namespace App\Entity;

use ApiPlatform\Metadata\ApiResource;
use ApiPlatform\Metadata\Get;
use ApiPlatform\Metadata\GraphQl\Mutation;
use ApiPlatform\Metadata\GraphQl\Query;
use ApiPlatform\Metadata\GraphQl\QueryCollection;
use App\Repository\DonneeVenteRepository;
use App\State\DonneeVenteProvider;
use App\State\DonneeVenteRandomProvider;
use Doctrine\DBAL\Types\Types;
use Doctrine\ORM\Mapping as ORM;

#[ApiResource (operations: [
    new Get(
        uriTemplate: "/vente/nombre",
        description: "Returns the number of sales sorted by date",
        name: "Nombre",
        provider: DonneeVenteProvider::class
    ),
    new Get(
        uriTemplate: "/vente/nombre/random",
        description: "Return random mock values",
        name: "Random",
        provider: DonneeVenteRandomProvider::class
    )
],
    graphQlOperations: [
        new Query(
            name: "Nombre",
            provider: DonneeVenteProvider::class
        ),
        new QueryCollection(
            resolver: DonneeVenteRandomProvider::class,
            name: "Random"
        ),
    ]
)]
class DonneeVente
{
    private ?\DateTimeInterface $date = null;

    private ?int $quantite = null;


    public function getDate(): ?\DateTimeInterface
    {
        return $this->date;
    }

    public function setDate(\DateTimeInterface $date): self
    {
        $this->date = $date;

        return $this;
    }

    public function getQuantite(): ?int
    {
        return $this->quantite;
    }

    public function setQuantite(int $quantite): self
    {
        $this->quantite = $quantite;

        return $this;
    }
}
